==> process-infinispan-persistence-springboot-0.12.0-sources.jar: org/acme/deals/Dealreviews_2_TaskInput.java <==
package org.acme.deals;

import java.util.Map;
import org.kie.kogito.UserTask;
import org.kie.kogito.UserTaskParam.ParamType;
import org.kie.kogito.UserTaskParam;

@UserTask(taskName = "review", processName = "Dealreviews")
public class Dealreviews_2_TaskInput {

    private String _id;

    private String _name;

    public void setId(String id) {
        this._id = id;
    }

    public String getId() {
        return this._id;
    }

    public void setName(String name) {
        this._name = name;
    }

    public String getName() {
        return this._name;
    }

    public static Dealreviews_2_TaskInput fromMap(String id, String name, Map<String, Object> params) {
        Dealreviews_2_TaskInput item = new Dealreviews_2_TaskInput();
        item._id = id;
        item._name = name;
        item.deal = (java.lang.String) params.get("deal");
        item.traveller = (org.acme.deals.Traveller) params.get("traveller");
        return item;
    }

    @UserTaskParam(value = ParamType.INPUT)
    private java.lang.String deal;

    public java.lang.String getDeal() {
        return deal;
    }

    public void setDeal(java.lang.String deal) {
        this.deal = deal;
    }

    @UserTaskParam(value = ParamType.INPUT)
    private org.acme.deals.Traveller traveller;

    public org.acme.deals.Traveller getTraveller() {
        return traveller;
    }

    public void setTraveller(org.acme.deals.Traveller traveller) {
        this.traveller = traveller;
    }
}
// Task input model for user task 'Review the deal' in process 'dealreviews'

==> process-infinispan-persistence-springboot-0.13.1-sources.jar: org/acme/deals/Dealreviews_2_TaskInput.java <==
package org.acme.deals;

import java.util.Map;
import org.kie.kogito.UserTask;
import org.kie.kogito.UserTaskParam.ParamType;
import org.kie.kogito.UserTaskParam;

@UserTask(taskName = "review", processName = "dealreviews")
public class Dealreviews_2_TaskInput {

    private String _id;

    private String _name;

    public void setId(String id) {
        this._id = id;
    }

    public String getId() {
        return this._id;
    }

    public void setName(String name) {
        this._name = name;
    }

    public String getName() {
        return this._name;
    }

    public static Dealreviews_2_TaskInput fromMap(String id, String name, Map<String, Object> params) {
        Dealreviews_2_TaskInput item = new Dealreviews_2_TaskInput();
        item._id = id;
        item._name = name;
        item.deal = (java.lang.String) params.get("deal");
        item.traveller = (org.acme.deals.Traveller) params.get("traveller");
        return item;
    }

    @UserTaskParam(value = ParamType.INPUT)
    private java.lang.String deal;

    public java.lang.String getDeal() {
        return deal;
    }

    public void setDeal(java.lang.String deal) {
        this.deal = deal;
    }

    @UserTaskParam(value = ParamType.INPUT)
    private org.acme.deals.Traveller traveller;

    public org.acme.deals.Traveller getTraveller() {
        return traveller;
    }

    public void setTraveller(org.acme.deals.Traveller traveller) {
        this.traveller = traveller;
    }
}
// Task input model for user task 'Review the deal' in process 'dealreviews'
